==> haskell-conduit-extra-1.1.11-4-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit-extra/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.1.11
id: conduit-extra-1.1.11-ff8bfc3f034dbe9a6e5b1cd3f1929886
key: condu_JKRKhZMH92DBBvaX6faO4m
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary Data.Conduit.Blaze
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Lazy Data.Conduit.Network Data.Conduit.Network.UDP
    Data.Conduit.Process Data.Conduit.Text Data.Conduit.Zlib
    Data.Conduit.Network.Unix
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-extra-1.1.11
hs-libraries: HSconduit-extra-1.1.11-JKRKhZMH92DBBvaX6faO4m
depends:
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-conduit-extra-1.1.12.1-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-conduit-extra/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: conduit-extra
version: 1.1.12.1
id: conduit-extra-1.1.12.1-34a75d65f1bcf0a6ace65de178beb2df
key: condu_4ZAuoOa8iIULHSHRXw1JQ1
license: MIT
maintainer: michael@snoyman.com
homepage: http://github.com/snoyberg/conduit
synopsis: Batteries included conduit: adapters for common libraries.
description:
    The conduit package itself maintains relative small dependencies. The purpose of this package is to collect commonly used utility functions wrapping other library dependencies, without depending on heavier-weight dependencies. The basic idea is that this package should only depend on haskell-platform packages and conduit.
category: Data, Conduit
author: Michael Snoyman
exposed: True
exposed-modules:
    Data.Conduit.Attoparsec Data.Conduit.Binary Data.Conduit.Blaze
    Data.Conduit.ByteString.Builder Data.Conduit.Filesystem
    Data.Conduit.Lazy Data.Conduit.Network Data.Conduit.Network.UDP
    Data.Conduit.Process Data.Conduit.Text Data.Conduit.Zlib
    Data.Conduit.Network.Unix
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.12.1
library-dirs: /usr/lib/ghc-7.10.3/site-local/conduit-extra-1.1.12.1
data-dir: /usr/share/arm-linux-ghc-7.10.3/conduit-extra-1.1.12.1
hs-libraries: HSconduit-extra-1.1.12.1-4ZAuoOa8iIULHSHRXw1JQ1
depends:
    async-2.1.0-b35f12010d11213b63d33c4f0cc6089c
    attoparsec-0.13.0.1-522c252ad233781393fab28c8daf023a
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    conduit-1.2.6.4-0dfd87f475e845002478c37d3a30df1e
    directory-1.2.2.0-17b2023f9d7e8036d19e6b52b4f75c98
    exceptions-0.8.2.1-8c1fe53cd5846ab1f6d4c58870c4f8d9
    filepath-1.4.0.0-73e0bec80594160bf6dd6cb25217c6bf
    monad-control-1.0.0.5-237b0aabd7893e5e3f4b9224e05c849c
    network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
    primitive-0.6.1.0-013c88e6ffae491f11ac3b8c0552ce0e
    process-1.2.3.0-21d25f1d78aeea6e68f1c768841f9794
    resourcet-1.1.7.3-3e7ca03abacc332d28328c69bbd74cd4
    stm-2.4.4.1-b43e402fc74ce6b0320fe4217e7e432d
    streaming-commons-0.1.15.2-e8e35f9b3c5e3a1a9d565bf7c4ec1900
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
    transformers-base-0.4.4-b65bc998c24abf50fea29d4891da9e32
haddock-interfaces: /usr/share/doc/haskell-conduit-extra/html/conduit-extra.haddock
haddock-html: /usr/share/doc/haskell-conduit-extra/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
